<?php
namespace AIOSEO\Plugin\Addon\LinkAssistant\Traits;

use AIOSEO\Plugin\Addon\LinkAssistant\Models;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Handles all data Vue needs for the Domains Report.
 *
 * @since 1.0.0
 */
trait DomainsReport {
	/**
	 * Returns the data for the Domains Report.
	 *
	 * @since 1.0.0
	 *
	 * @param  int    $offset     The offset.
	 * @param  string $searchTerm An optional search term.
	 * @return array              The data.
	 */
	public function getDomainsReportData( $offset = 0, $searchTerm = '' ) {
		$whereClause = $this->getDomainsReportWhereClause( $searchTerm );
		$domains     = Models\Link::getDomains( $offset, $whereClause );
		$total       = Models\Link::getTotalDomains( $whereClause );
		$page        = 0 === $offset ? 1 : ( $offset / 10 ) + 1;

		return [
			'rows'        => $domains,
			'totals'      => [
				'page'  => $page,
				'pages' => ceil( $total / 10 ),
				'total' => $total
			],
			'tableFields' => [
				'searchTerm'    => $searchTerm,
				'paginatedPage' => $page
			]
		];
	}

	/**
	 * Get a where clause for the Domains Report search term.
	 *
	 * @since 1.0.0
	 *
	 * @param  string $searchTerm The search term.
	 * @return string             The search where clause.
	 */
	private function getDomainsReportWhereClause( $searchTerm ) {
		if ( 'null' === $searchTerm || ! $searchTerm ) {
			return '';
		}

		$searchTerm = esc_sql( $searchTerm );
		if ( ! $searchTerm ) {
			return '';
		}

		$where = '';
		if ( intval( $searchTerm ) ) {
			$where .= '
				id = ' . (int) $searchTerm . ' OR
				post_id = ' . (int) $searchTerm . ' OR
			';
		}
		$where .= 'hostname LIKE \'%' . $searchTerm . '%\'';

		return "( $where )";
	}
}